@@ -48,7 +48,7 @@ class EventsManager extends CGExtensions
 			$name = $this->Lang('friendlyname');
 		return $name;
 	}
-	function GetVersion() { return '0.1.4'; }
+	function GetVersion() { return '0.1.5'; }
 	function GetHelp() { return $this->Lang('help'); }
 	function GetAuthor() { return 'AireLibre'; }
 	function GetAuthorEmail() { return 'contact@airelibre.fr'; }
@@ -111,6 +111,7 @@ class EventsManager extends CGExtensions
 		$this->SetParameterType('show',CLEAN_STRING);
 		$this->SetParameterType('start_datetime', CLEAN_STRING);
 		$this->SetParameterType('end_datetime', CLEAN_STRING);
+		$this->SetParameterType('myevents', CLEAN_INT);
 		
 		// Templates
 		$this->SetParameterType('summarytemplate', CLEAN_STRING);
@@ -129,6 +130,7 @@ class EventsManager extends CGExtensions
 		$this->CreateParameter('show', 'upcoming', $this->Lang('param_show'));
 		$this->CreateParameter('start_datetime', '', $this->Lang('param_start_datetime'));
 		$this->CreateParameter('end_datetime', '', $this->Lang('param_end_datetime'));
+		$this->CreateParameter('myevents', 'false', $this->Lang('param_myevents'));
 		
 		// Templates
 		$this->CreateParameter('summarytemplate', '', $this->Lang('param_summarytemplate'));
