@@ -152,6 +152,8 @@ $lang['param_end_datetime'] = "Useful only with the <em>default</em> action, and
 $lang['param_summarytemplate'] = "Useful only with the <em>default</em> action, this parameter specifies the template that should be used for the summary mode display. If no value is specified, the default template of that type is used";
 $lang['param_detailtemplate'] = "Useful only with the <em>detail</em> action, this parameter specifies the template that should be used for the detail mode display. If no value is specified, the default template of that type is used";
 $lang['param_registrationtemplate'] = "Useful only with the <em>register</em> action, this parameter specifies the template that should be used for the registrater mode display. If no value is specified, the default template of that type is used";
+$lang['param_myevents'] = "true/false - Utilisé uniquement avec l'action <em>default</em>, affiche uniquement les évènements auxquels l'utilisateur FEU actuellement connecté est enregistré. Si personne n'est connecté, le paramètre est ignoré";
+$lang['param_myevents'] = "true/false - Useful only with the <em>default</em> action, with this parameter you can display only the events the current logged in FEUser is registered to. If no one is connected, this parameter is simply ignored - Tip: use this option on a private FEU page";
 
 # Help
 $lang['help'] = "
@@ -164,6 +166,8 @@ $lang['help'] = "
 	<li>Create one or more events in the admin</li>
 	<li>Add the <strong>{EventsManager}</strong> tag to a page to display an upcoming events summary view</li>
 </ul>
+<h3>Only display the current logged in FEUser events</h3>
+<p>Simply use the <strong>myevents</strong> parameter this way: <strong>{EventsManager myevents=true}</strong></p>
 <p>You can customize your templates with some parameters and options (see below)</p>
 
 <h3>Support</h3>
@@ -178,5 +182,7 @@ $lang['help'] = "
 <p>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</p>
 <p>However, as a special exception to the GPL, this software is distributed as an addon module to CMS Made Simple. You may not use this software in any Non GPL version of CMS Made simple, or in any version of CMS Made simple that does not indicate clearly and obviously in its admin section that the site was built with CMS Made simple.</p>
 <p>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA Or <a
-href=\"http://www.gnu.org/licenses/licenses.html#GPL\" target=\"_blank\">read it online</a></p>";
+href=\"http://www.gnu.org/licenses/licenses.html#GPL\" target=\"_blank\">read it online</a></p>
+<p>The module icon has be designed by Everaldo - You can download some nice icons on: <a href='http://www.everaldo.com' target='_blank'>www.everaldo.com</a></p>
+";
 ?>
\ No newline at end of file
