@@ -148,6 +148,7 @@ $lang['param_end_datetime'] = "Utilisé uniquement avec l'action <em>default</em
 $lang['param_summarytemplate'] = "Utilisé uniquement avec l'action <em>default</em>, vous permet de préciser le gabarit à utiliser pour l'affichage de la liste des évènements - Si rien n'est spécifié, le gabarit par défaut sera utilisé";
 $lang['param_detailtemplate'] = "Utilisé uniquement avec les actions <em>default</em> et <em>detail</em>, vous permet de préciser le gabarit à utiliser pour l'affichage d'un évènement - Si rien n'est spécifié, le gabarit par défaut sera utilisé";
 $lang['param_registrationtemplate'] = "Utilisé uniquement avec l'action <em>register</em>, vous permet de préciser le gabarit à utiliser pour l'affichage du formulaire d'inscription à un évènement - Si rien n'est spécifié, le gabarit par défaut sera utilisé";
+$lang['param_myevents'] = "true/false - Utilisé uniquement avec l'action <em>default</em>, affiche uniquement les évènements auxquels l'utilisateur FEU actuellement connecté est enregistré. Si personne n'est connecté, le paramètre est ignoré - Astuce : utilisez cette option sur une page de type 'Contenu protégé'";
 
 # Help
 $lang['help'] = "
@@ -160,6 +161,8 @@ $lang['help'] = "
 <li>Ajoutez la balise : <strong>{EventsManager}</strong>
 à une page pour afficher la liste des évènements à venir</li>
 </ul>
+<h3>Afficher uniquement les évènements auxquels l'utilisateur FEU connecté s'est enregistré</h3>
+<p>Utilisez simplement le paramètre <strong>myevents</strong> de cette manière : <strong>{EventsManager myevents=true}</strong></p>
 <p>Pour personnaliser d'avantage votre liste d'évènements, consultez la liste des options disponibles en bas de cette page. Vous pouvez aussi personnaliser vos gabarits d'affichage grâce à Smarty.</p>
 <h3>Assistance</h3>
 <p>Ce module est fourni sans aucune assistance commerciale. Cependant,
@@ -197,6 +200,6 @@ d'une mise à jour du module. L'auteur du module ne pourrait être tenu
 pour responsable de tout dysfonctionnement du site provenant de ce
 module. Pour plus d'informations, <a
 href=\"http://www.gnu.org/licenses/licenses.html#GPL\" target=\"_blank\">consultez
-la licence GNU GPL</a>.<br>
-</p>";
+la licence GNU GPL</a>.</p>
+<p>L'icône du module a été créée par Everaldo. Vous pouvez télécharger ses belles icônes sur : <a href='http://www.everaldo.com' target='_blank'>www.everaldo.com</a></p>";
 ?>
\ No newline at end of file
